rnalysis.filtering.HTCountFilter.split\_by\_bigtable\_group
===========================================================

.. currentmodule:: rnalysis.filtering

.. automethod:: HTCountFilter.split_by_bigtable_group